@@ -91,7 +91,7 @@ end
 -- up to the that total. Returning values that don't add up may produce
 -- unexpected results.
 --
--- TeX wizards shall also note that this is slighty different from
+-- TeX wizards shall also note that this is slightly different from
 -- Knuth's definition "nline l1 i1 l2 i2 ... lN iN".
 function lineBreak:parShape(_)
   return 0, self.hsize, 0
@@ -156,7 +156,7 @@ function lineBreak:tryBreak() -- 855
   if not node then pi = ejectPenalty; breakType = "hyphenated"
   elseif node.is_discretionary then breakType = "hyphenated"; pi = param("hyphenPenalty")
   else breakType = "unhyphenated"; pi = node.penalty or 0 end
-  if debugging then SU.debug("break", "Trying a "..breakType.." break p="..pi) end
+  if debugging then SU.debug("break", "Trying a ", breakType, "break p =", pi) end
   self.no_break_yet = true -- We have to store all this state crap in the object, or it's global variables all the way
   self.prev_prev_r = nil
   self.prev_r = self.activeListHead
@@ -166,9 +166,9 @@ function lineBreak:tryBreak() -- 855
   while true do
     while true do -- allows "break" to function as "continue"
       self.r = self.prev_r.next
-      if debugging then SU.debug("break", "We have moved the link  forward, ln is now "..(self.r.type == "delta" and "XX" or self.r.lineNumber)) end
+      if debugging then SU.debug("break", "We have moved the link  forward, ln is now", self.r.type == "delta" and "XX" or self.r.lineNumber) end
       if self.r.type == "delta" then -- 858
-        if debugging then SU.debug("break", " Adding delta node width of ".. tostring(self.r.width)) end
+        if debugging then SU.debug("break", " Adding delta node width of", self.r.width) end
         self.curActiveWidth:___add(self.r.width)
         self.prev_prev_r = self.prev_r
         self.prev_r = self.r
@@ -176,7 +176,7 @@ function lineBreak:tryBreak() -- 855
       end
       -- 861
       if self.r.lineNumber > self.old_l then
-        if debugging then SU.debug("break", "Mimimum demerits = " .. self.minimumDemerits) end
+        if debugging then SU.debug("break", "Minimum demerits = " .. self.minimumDemerits) end
         if self.minimumDemerits < awful_bad and (self.old_l ~= self.easy_line or self.r == self.activeListHead) then
           self:createNewActiveNodes(breakType)
         end
@@ -496,7 +496,7 @@ function lineBreak:describeBreakNode(node)
   local after = self.nodes[node.curBreak+1]
   local from = node.prevBreak and node.prevBreak.curBreak or 1
   local to = node.curBreak
-  return "b "..from.."-"..to.." \""..(before and before:toText()).." | "..(after and after:toText()).."\" [".. node.totalDemerits..", "..node.fitness.."]"
+  return ("b %s-%s \"%s | %s\" [%s, %s]"):format(from, to, before and before:toText() or "", after and after:toText() or "", node.totalDemerits, node.fitness)
 end
 
 -- NOTE: this function is called many thousands of times even in single
@@ -694,9 +694,13 @@ end
 
 function lineBreak:dumpActiveRing()
   local p = self.activeListHead
-  io.stderr:write("\n")
+  if not SILE.quiet then
+    io.stderr:write("\n")
+  end
   repeat
-    if p == self.r then io.stderr:write("-> ") else io.stderr:write("   ") end
+    if not SILE.quiet then
+      if p == self.r then io.stderr:write("-> ") else io.stderr:write("   ") end
+    end
     SU.debug("break", lineBreak:describeBreakNode(p))
     p = p.next
   until p == self.activeListHead
